Name:           pmacct
Version:        1.7.2
Release:        1%{?dist}
Summary:        Accounting and aggregation toolsuite for IPv4 and IPv6

License:        GPLv2+
URL:            http://www.pmacct.net/
Source0:        http://www.pmacct.net/pmacct-%{version}.tar.gz
Source1:        nfacctd.service
Source2:        nfacctd
Source3:        pmacctd.service
Source4:        pmacctd
Source5:        pmbgpd.service
Source6:        pmbgpd
Source7:        pmbmpd.service
Source8:        pmbmpd
Source9:        pmtelemetryd.service
Source10:       pmtelemetryd
Source11:       sfacctd.service
Source12:       sfacctd
Source13:       uacctd.service
Source14:       uacctd

BuildRequires:  libpcap-devel
#BuildRequires:  mariadb-connector-c-devel
BuildRequires:  postgresql-devel
BuildRequires:  mongo-c-driver-devel
BuildRequires:  sqlite-devel
BuildRequires:  librabbitmq-devel
BuildRequires:  zeromq-devel >= 4.2.0
BuildRequires:  librdkafka-devel
BuildRequires:  GeoIP-devel
BuildRequires:  libmaxminddb-devel
BuildRequires:  jansson-devel
BuildRequires:  avro-c-devel
BuildRequires:  libnetfilter_log-devel
BuildRequires:  zlib-devel

BuildRequires:	systemd
%{?systemd_requires}

%description
pmacct is a small set of passive network monitoring tools to measure, account,
classify and aggregate IPv4 and IPv6 traffic; a pluggable and flexible
architecture allows to store the collected traffic data into memory tables or
SQL (MySQL, SQLite, PostgreSQL) databases. pmacct supports fully customizable
historical data breakdown, flow sampling, filtering and tagging, recovery
actions, and triggers. Libpcap, sFlow v2/v4/v5 and NetFlow v1/v5/v7/v8/v9 are
supported, both unicast and multicast. Also, a client program makes it easy to
export data to tools like RRDtool, GNUPlot, Net-SNMP, MRTG, and Cacti.


%prep
%autosetup


%build
%configure \
    --enable-plabel \
    --enable-sqlite3 \
    --enable-rabbitmq \
    --enable-zmq \
    --enable-kafka \
    --enable-geoipv2 \
    --enable-jansson \
    --enable-avro \
    --enable-nflog \
    --docdir=/usr/share/doc/pmacct

# Disabled Dependencies
#    --enable-ndpi \	# Not in Fedora
#    --enable-mysql \   # Not in CentOS
#    --enable-pgsql \   # Wrong version in CentOS?

%make_build V=1


%install
rm -rf $RPM_BUILD_ROOT
%make_install

# install sample configuration files
install -Dp examples/nfacctd-sql.conf.example %{buildroot}/%{_sysconfdir}/%{name}/nfacctd.conf
install -Dp examples/pmacctd-sql.conf.example %{buildroot}/%{_sysconfdir}/%{name}/pmacctd.conf

# install systemd units
install -d %{buildroot}/%{_unitdir} %{buildroot}/%{_sysconfdir}/sysconfig
install %{S:1} %{S:3} %{S:5} %{S:7} %{S:9}  %{S:11} %{S:13} %{buildroot}/%{_unitdir}
install %{S:2} %{S:4} %{S:6} %{S:8} %{S:10} %{S:12} %{S:14} %{buildroot}/%{_sysconfdir}/sysconfig

%post
%systemd_post nfacctd.service
%systemd_post pmacctd.service
%systemd_post pmbgpd.service
%systemd_post pmbmpd.service
%systemd_post pmtelemetryd.service
%systemd_post sfacctd.service
%systemd_post uacctd.service

%preun
%systemd_preun nfacctd.service
%systemd_preun pmacctd.service
%systemd_preun pmbgpd.service
%systemd_preun pmbmpd.service
%systemd_preun pmtelemetryd.service
%systemd_preun sfacctd.service
%systemd_preun uacctd.service

%postun
%systemd_postun_with_restart nfacctd.service
%systemd_postun_with_restart pmacctd.service
%systemd_postun_with_restart pmbgpd.service
%systemd_postun_with_restart pmbmpd.service
%systemd_postun_with_restart pmtelemetryd.service
%systemd_postun_with_restart sfacctd.service
%systemd_postun_with_restart uacctd.service

%files
%license COPYING
%doc docs examples sql
%doc AUTHORS ChangeLog CONFIG-KEYS FAQS INSTALL QUICKSTART UPGRADE
%config(noreplace) %{_sysconfdir}/pmacct/nfacctd.conf
%config(noreplace) %{_sysconfdir}/pmacct/pmacctd.conf
%config(noreplace) %{_sysconfdir}/sysconfig/nfacctd
%config(noreplace) %{_sysconfdir}/sysconfig/pmacctd
%config(noreplace) %{_sysconfdir}/sysconfig/pmbgpd
%config(noreplace) %{_sysconfdir}/sysconfig/pmbmpd
%config(noreplace) %{_sysconfdir}/sysconfig/pmtelemetryd
%config(noreplace) %{_sysconfdir}/sysconfig/sfacctd
%config(noreplace) %{_sysconfdir}/sysconfig/uacctd
%{_datarootdir}/pmacct
%{_bindir}/pmacct
%{_sbindir}/nfacctd
%{_sbindir}/pmacctd
%{_sbindir}/pmbgpd
%{_sbindir}/pmbmpd
%{_sbindir}/pmtelemetryd
%{_sbindir}/sfacctd
%{_sbindir}/uacctd
%{_unitdir}/nfacctd.service
%{_unitdir}/pmacctd.service
%{_unitdir}/pmbgpd.service
%{_unitdir}/pmbmpd.service
%{_unitdir}/pmtelemetryd.service
%{_unitdir}/sfacctd.service
%{_unitdir}/uacctd.service


%changelog
* Thu Jun 14 2018 Felix Kaechele <heffer@fedoraproject.org>
- initial package
